@@ -210,11 +210,11 @@ class MindsDBParser(Parser):
             params=params,
             if_not_exists=p.if_not_exists_or_empty
         )
-    
+
     @_('DROP AGENT if_exists_or_empty identifier')
     def drop_agent(self, p):
         return DropAgent(name=p.identifier, if_exists=p.if_exists_or_empty)
-    
+
     @_('UPDATE AGENT identifier SET kw_parameter_list')
     @_('ALTER AGENT identifier USING kw_parameter_list')
     def update_agent(self, p):
@@ -667,11 +667,13 @@ class MindsDBParser(Parser):
                       from_select=p.select)
 
     # INSERT
-    @_('INSERT INTO identifier LPAREN column_list RPAREN union',
+    @_('INSERT INTO identifier LPAREN column_list RPAREN select',
+       'INSERT INTO identifier LPAREN column_list RPAREN union',
+       'INSERT INTO identifier select',
        'INSERT INTO identifier union')
     def insert(self, p):
         columns = getattr(p, 'column_list', None)
-        query = p.union
+        query = p.select if hasattr(p, 'select') else p.union
         return Insert(table=p.identifier, columns=columns, from_select=query)
 
     @_('INSERT INTO identifier LPAREN column_list RPAREN VALUES expr_list_set',
@@ -1084,24 +1086,33 @@ class MindsDBParser(Parser):
         return {'identifier':p.identifier, 'engine':engine, 'if_not_exists':p.if_not_exists_or_empty}
 
     # Combining
-    @_('union UNION select',
+    @_('select UNION select',
+       'union UNION select',
+       'select UNION ALL select',
        'union UNION ALL select',
+       'select UNION DISTINCT select',
        'union UNION DISTINCT select')
     def union(self, p):
         unique = not hasattr(p, 'ALL')
         distinct_key = hasattr(p, 'DISTINCT')
         return Union(left=p[0], right=p[-1], unique=unique, distinct_key=distinct_key)
 
-    @_('union INTERSECT select',
+    @_('select INTERSECT select',
+       'union INTERSECT select',
+       'select INTERSECT ALL select',
        'union INTERSECT ALL select',
+       'select INTERSECT DISTINCT select',
        'union INTERSECT DISTINCT select')
     def union(self, p):
         unique = not hasattr(p, 'ALL')
         distinct_key = hasattr(p, 'DISTINCT')
         return Intersect(left=p[0], right=p[-1], unique=unique, distinct_key=distinct_key)
 
-    @_('union EXCEPT select',
+    @_('select EXCEPT select',
+       'union EXCEPT select',
+       'select EXCEPT ALL select',
        'union EXCEPT ALL select',
+       'select EXCEPT DISTINCT select',
        'union EXCEPT DISTINCT select')
     def union(self, p):
         unique = not hasattr(p, 'ALL')
@@ -1113,9 +1124,11 @@ class MindsDBParser(Parser):
     def select(self, p):
         return p[1]
 
-    @_('select')
+    @_('LPAREN union RPAREN')
     def union(self, p):
-        return p[0]
+        node = p[1]
+        node.parentheses = True
+        return node
 
     # WITH
     @_('ctes select')
@@ -1124,7 +1137,8 @@ class MindsDBParser(Parser):
         select.cte = p.ctes
         return select
 
-    @_('ctes COMMA identifier cte_columns_or_nothing AS LPAREN union RPAREN')
+    @_('ctes COMMA identifier cte_columns_or_nothing AS LPAREN select RPAREN',
+       'ctes COMMA identifier cte_columns_or_nothing AS LPAREN union RPAREN')
     def ctes(self, p):
         ctes = p.ctes
         ctes = ctes + [
@@ -1135,7 +1149,8 @@ class MindsDBParser(Parser):
         ]
         return ctes
 
-    @_('WITH identifier cte_columns_or_nothing AS LPAREN union RPAREN')
+    @_('WITH identifier cte_columns_or_nothing AS LPAREN select RPAREN',
+       'WITH identifier cte_columns_or_nothing AS LPAREN union RPAREN')
     def ctes(self, p):
         return [
             CommonTableExpression(
@@ -1508,11 +1523,12 @@ class MindsDBParser(Parser):
 
     # OPERATIONS
 
-    @_('LPAREN union RPAREN')
+    @_('LPAREN select RPAREN',
+       'LPAREN union RPAREN')
     def expr(self, p):
-        union = p.union
-        union.parentheses = True
-        return union
+        node = p[1]
+        node.parentheses = True
+        return node
 
     @_('LPAREN expr RPAREN')
     def expr(self, p):
